@@ -4,6 +4,7 @@ context("mcfs")
 #devtools::use_test("test.mcfs")
 
 test_that("MCFS mode 2", {
+  skip_on_cran()
   options(java.parameters = "-Xmx4g")
   require(testthat)
   require(rmcfs)
@@ -17,12 +18,12 @@ test_that("MCFS mode 2", {
   showme(adata)
   
   # Parametrize and run MCFS-ID procedure
-  result <- mcfs(class~., adata, cutoffPermutations = 3, mode = 2, featureFreq = 50,
+  result <- mcfs(class~., adata, cutoffPermutations = 3, mode = 2, featureFreq = 20,
                  buildID = TRUE, finalCV = TRUE, finalRuleset = FALSE, 
                  threadsNumber = 1, seed = 1)
 
   expect_that(result, is_a("mcfs"))
-  expect_that(all(c('RI','ID', 'RI_mode_2') %in% names(result)), is_true())
+  expect_true(all(c('RI','ID', 'RI_mode_2') %in% names(result)))
   expect_that(nrow(result$RI_mode_2$phase_1), equals(117))
   #expect_that(nrow(result$RI_mode_2$phase_2), equals(25))
   expect_that(nrow(result$RI_mode_2$phase_1[startsWith(result$RI_mode_2$phase_1$attribute, "mcfs_contrast_attr"),]),equals(11))
